@@ -4,17 +4,17 @@
 modname = "fluid_design_system"
 distname = "cubicweb-fluid-design-system"
 
-numversion = (1, 9, 2)
+numversion = (1, 10, 0)
 version = ".".join(str(num) for num in numversion)
 
 license = "LGPL"
 author = "LOGILAB S.A. (Paris, FRANCE)"
 author_email = "contact@logilab.fr"
 description = ""
-web = "https://www.cubicweb.org/project/%s" % distname
+web = ""
 
 __depends__ = {
-    "cubicweb": ">= 3.35.0",
+    "cubicweb": ">= 3.38.0, < 3.39.0",
 }
 __recommends__ = {}
 
