@@ -12,8 +12,8 @@ from logilab.common.decorators import monkeypatch
 from logilab.mtconverter import xml_escape
 
 from cubicweb import tags
-from cubicweb.web.component import Link
-from cubicweb.web.views import basecomponents
+from cubicweb_web.component import Link
+from cubicweb_web.views import basecomponents
 from cubicweb.uilib import js
 
 from cubicweb_fluid_design_system.views import utils
