@@ -12,7 +12,7 @@ from logilab.common.decorators import monkeypatch
 from logilab.mtconverter import xml_escape
 
 from cubicweb.utils import wrap_on_write
-from cubicweb.web.views import boxes
+from cubicweb_web.views import boxes
 
 boxes.SearchBox.formdef = (
     '<form action="%(action)s" id="search_box" class="navbar-form" role="search">\n'
