@@ -12,7 +12,7 @@ from logilab.common.decorators import monkeypatch
 from logilab.common.textutils import unormalize
 from logilab.mtconverter import xml_escape
 
-from cubicweb.web.views import startup, uicfg
+from cubicweb_web.views import startup, uicfg
 
 startup.ManageView.box_html = """<div class="panel panel-default">
     <div class="panel-heading">
