@@ -10,7 +10,7 @@ __docformat__ = "restructuredtext en"
 from logilab.common.decorators import monkeypatch
 
 from cubicweb import utils
-from cubicweb.web.views import tabs
+from cubicweb_web.views import tabs
 
 
 @monkeypatch(tabs.TabsMixin)
